@@ -2,7 +2,7 @@ require 'spec_helper'
 
 describe 'glance::api' do
   let :pre_condition do
-    "class { '::glance::api::authtoken':
+    "class { 'glance::api::authtoken':
       password => 'ChangeMe',
     }"
   end
@@ -11,23 +11,18 @@ describe 'glance::api' do
     {
       :bind_host                => '<SERVICE DEFAULT>',
       :bind_port                => '9292',
-      :registry_host            => '0.0.0.0',
-      :registry_port            => '<SERVICE DEFAULT>',
-      :registry_client_protocol => '<SERVICE DEFAULT>',
       :auth_strategy            => 'keystone',
       :enabled                  => true,
       :manage_service           => true,
       :backlog                  => '<SERVICE DEFAULT>',
       :workers                  => '7',
       :show_image_direct_url    => '<SERVICE DEFAULT>',
-      :show_multiple_locations  => '<SERVICE DEFAULT>',
       :filesystem_store_metadata_file => '<SERVICE DEFAULT>',
       :filesystem_store_file_perm => '<SERVICE DEFAULT>',
       :location_strategy        => '<SERVICE DEFAULT>',
       :purge_config             => false,
       :delayed_delete           => '<SERVICE DEFAULT>',
       :scrub_time               => '<SERVICE DEFAULT>',
-      :default_store            => false,
       :image_cache_dir          => '/var/lib/glance/image-cache',
       :image_import_plugins     => '<SERVICE DEFAULT>',
       :image_conversion_output_format => '<SERVICE DEFAULT>',
@@ -38,7 +33,6 @@ describe 'glance::api' do
       :image_member_quota       => '<SERVICE DEFAULT>',
       :image_cache_stall_time   => '<SERVICE DEFAULT>',
       :image_cache_max_size     => '<SERVICE DEFAULT>',
-      :os_region_name           => 'RegionOne',
       :pipeline                 => 'keystone',
       :task_time_to_live        => '<SERVICE DEFAULT>',
       :task_executor            => '<SERVICE DEFAULT>',
@@ -83,7 +77,6 @@ describe 'glance::api' do
         :image_member_quota       => '128',
         :image_cache_stall_time   => '10',
         :image_cache_max_size     => '10737418240',
-        :os_region_name           => 'RegionOne2',
         :pipeline                 => 'keystone2',
         :sync_db                  => false,
         :limit_param_default      => '10',
@@ -180,15 +173,6 @@ describe 'glance::api' do
           end
         end
 
-        it 'is_expected.to lay down default glance_store api and cache config' do
-          [
-            'os_region_name',
-          ].each do |config|
-            is_expected.to contain_glance_cache_config("glance_store/#{config}").with_value(param_hash[config.intern])
-            is_expected.to contain_glance_api_config("glance_store/#{config}").with_value(param_hash[config.intern])
-          end
-        end
-
         it 'is_expected.to lay down default glance_store api config' do
           [
             'filesystem_store_metadata_file',
@@ -323,14 +307,74 @@ describe 'glance::api' do
       end
     end
 
-    describe 'with stores by default' do
+    describe 'with enabled_backends and stores by default' do
       let :params do
         default_params
       end
 
+      it { is_expected.to_not contain_glance_api_config('DEFAULT/enabled_backends').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to_not contain_glance_api_config('glance_store/stores').with_value('<SERVICE DEFAULT>') }
     end
 
+    describe 'with enabled_backends' do
+      let :params do
+        default_params.merge({
+          :enabled_backends => ['file1:file','http1:http'],
+          :default_backend  => 'file1',
+          :stores           => ['file','http'],
+          :default_store    => 'file',
+        })
+      end
+
+      it { is_expected.to contain_glance_api_config('DEFAULT/enabled_backends').with_value('file1:file,http1:http') }
+      it { is_expected.to contain_glance_api_config('glance_store/default_backend').with_value('file1') }
+      it { is_expected.to contain_glance_api_config('glance_store/stores').with_ensure('absent') }
+      it { is_expected.to contain_glance_api_config('glance_store/default_store').with_ensure('absent') }
+    end
+
+    describe 'with invalid backend type' do
+      let :params do
+        default_params.merge({
+          :enabled_backends => ['file1:file','bad1:mybad'],
+          :default_backend  => 'file',
+        })
+      end
+
+      it_raises 'a Puppet::Error', / is not a valid backend type./
+    end
+
+    describe 'with enabled_backends but no default_backend' do
+      let :params do
+        default_params.merge({
+          :enabled_backends => ['file1:file','http1:http'],
+        })
+      end
+
+      it_raises 'a Puppet::Error', /A glance default_backend must be specified./
+    end
+
+    describe 'with duplicate backend identifiers' do
+      let :params do
+        default_params.merge({
+          :enabled_backends => ['file1:file','file1:http'],
+          :default_backend  => 'file1',
+        })
+      end
+
+      it_raises 'a Puppet::Error', /All backend identifiers in enabled_backends must be unique./
+    end
+
+    describe 'with invalid default_backend' do
+      let :params do
+        default_params.merge({
+          :enabled_backends => ['file1:file','http1:http'],
+          :default_backend  => 'file2',
+        })
+      end
+
+      it_raises 'a Puppet::Error', / is not a valid backend identifier./
+    end
+
     describe 'with stores override' do
       let :params do
         default_params.merge({
